@@ -69,13 +69,6 @@ GtkWidget *hildon_home_window_new                  (void);
 
 GtkWidget *hildon_home_window_get_titlebar         (HildonHomeWindow *window);
 
-void       hildon_home_window_show_information_note(HildonHomeWindow *window,
-                                                    const gchar *text);
-
-void       hildon_home_window_show_information_banner
-                                                   (HildonHomeWindow *window,
-                                                    const gchar *text);
-
 void       hildon_home_window_applets_init         (HildonHomeWindow *window);
 
 void       hildon_home_window_select_applets       (HildonHomeWindow *window);
